# -*- coding: UTF-8 -*-
import re
import os
import pwd
import grp
from stat import S_IMODE


def get_tags():
    return ['2', '2.2']


def get_usr_grp_mode(file_name):
    '''get user,group,mode'''
    stat_ste = os.stat(file_name)
    user = pwd.getpwuid(stat_ste.st_uid).pw_name
    group = grp.getgrgid(stat_ste.st_gid).gr_name
    filemode = "%04o" % S_IMODE(stat_ste.st_mode)
    return user, group, filemode


def match_permission(file_name, obtained_usr, obtained_grp, obtained_mode):
    """Permission compare
    file_name:path to file
    obtained_usr:user
    obtained_grp:group
    obtained_mode:file mode
    rtype:bool
    """
    if file_name == "/etc/shadow":
        MATCH_EXCEPT_MODE = re.compile(r'^0[04]00$')
    elif file_name in ['/etc/xinetd.conf', '/etc/security']:
        MATCH_EXCEPT_MODE = re.compile(r'^0[0246]00$')
    else:
        MATCH_EXCEPT_MODE = re.compile(r'^0[0246][04][04]$')
    logic_pass = obtained_usr == "root" and obtained_grp == "root" and MATCH_EXCEPT_MODE.match(obtained_mode)
    if logic_pass:
        return True
    return False


def run_task(runcontext):
    curtemplate = runcontext.get_template()
    ret_code = -1
    tmp_vars = {}
    tmp_vars["policyresult"] = "failed"
    tmp_vars["checkresult1"] = "failed"
    tmp_vars["systemvalue1"] = ""
    tmp_vars["checkresult2"] = "failed"
    tmp_vars["systemvalue2"] = ""
    tmp_vars["checkresult3"] = "failed"
    tmp_vars["systemvalue3"] = ""
    tmp_vars["checkresult4"] = "failed"
    tmp_vars["systemvalue4"] = ""
    tmp_vars["checkresult5"] = "failed"
    tmp_vars["systemvalue5"] = ""
    tmp_vars["checkresult6"] = "failed"
    tmp_vars["systemvalue6"] = ""

    file_list = ["/etc/passwd", "/etc/shadow", "/etc/group", "/etc/services", "/etc/xinetd.conf", "/etc/security"]
    i = 0
    for file_name in file_list:
        i += 1
        if os.path.exists(file_name):
            user, group, filemode = get_usr_grp_mode(file_name)
            tmp_vars["systemvalue{0}".format(i)] = "%s\t%s:%s\t%s" % (file_name, user, group, filemode)
            check_value = match_permission(file_name, user, group, filemode)
            if check_value:
                tmp_vars["checkresult{0}".format(i)] = "pass"
        else:
            tmp_vars["systemvalue{0}".format(i)] = '%s is not exists.' % file_name
            tmp_vars["checkresult{0}".format(i)] = "pass"

    if tmp_vars["checkresult1"] == "pass" and tmp_vars["checkresult2"] == "pass" and tmp_vars["checkresult3"] == "pass" and tmp_vars["checkresult4"] == "pass" and tmp_vars["checkresult5"] == "pass" and tmp_vars["checkresult6"] == "pass":
        ret_code = 0
        tmp_vars["policyresult"] = "pass"

    rc, out = curtemplate.render(runcontext.get_template_file('t_2_2.j2'), **tmp_vars)

    if rc == False:
        return (-2, "Failed to render template.%s" % out)

    return ret_code, out
