# -*- coding: UTF-8 -*-
import re
import json


def get_tags():
    return ['8', '8.14']


def run_task(runcontext):
    ansible_params = runcontext.get_mod_params_instance()
    runcontext.set_mod_params_instance(ansible_params, "chdir", None)
    runcontext.set_mod_params_instance(ansible_params, "executable", None)

    module = runcontext.get_module_file("shell.py")
    rc, out = run_audit(runcontext, ansible_params, module)
    return rc, out


def run_audit(runcontext, ansible_params, module):
    curtemplate = runcontext.get_template()
    ret_code = -1
    tmp_vars = {}
    tmp_vars["policyresult"] = "failed"

    tmp_vars["checkresult1"] = "failed"
    tmp_vars["scancommand1"] = r'''grep session /etc/audit/rules.d/*.rules 2>/dev/null | egrep '/var/run/utmp' | grep wa | grep -v '^\s*#' '''
    tmp_vars["systemvalue1"] = ""

    tmp_vars["checkresult2"] = "failed"
    tmp_vars["scancommand2"] = r'''grep session /etc/audit/rules.d/*.rules 2>/dev/null | egrep '/var/log/wtmp' | grep wa | grep -v '^\s*#' '''
    tmp_vars["systemvalue2"] = ""

    tmp_vars["checkresult3"] = "failed"
    tmp_vars["scancommand3"] = r'''grep session /etc/audit/rules.d/*.rules 2>/dev/null | egrep '/var/log/btmp' | grep wa | grep -v '^\s*#' '''
    tmp_vars["systemvalue3"] = ""

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand1"])
    arc1, astdout1, astderr1 = runcontext.invoke_module(module, ansible_params)
    runcontext.log_debug_invoke_result(arc1, astdout1, astderr1)
    runcontext.sleep()

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand2"])
    arc2, astdout2, astderr2 = runcontext.invoke_module(module, ansible_params)
    runcontext.log_debug_invoke_result(arc2, astdout2, astderr2)
    runcontext.sleep()

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand3"])
    arc3, astdout3, astderr3 = runcontext.invoke_module(module, ansible_params)
    runcontext.log_debug_invoke_result(arc3, astdout3, astderr3)
    runcontext.sleep()

    if arc1 != 0:
        return (-2, "Failed to invoke module: %s." % astdout1)
    resultjson1 = json.loads(astdout1)
    astdout1 = resultjson1["stdout"]
    astderr1 = resultjson1["stderr"]
    match1 = re.match(r".+", astdout1)
    tmp_vars["systemvalue1"] = astdout1
    if match1:
        tmp_vars["checkresult1"] = "pass"

    if arc2 != 0:
        return (-2, "Failed to invoke module: %s." % astdout2)
    resultjson2 = json.loads(astdout2)
    astdout2 = resultjson2["stdout"]
    astderr2 = resultjson2["stderr"]
    match2 = re.match(r".+", astdout2)
    tmp_vars["systemvalue2"] = astdout2
    if match2:
        tmp_vars["checkresult2"] = "pass"

    if tmp_vars["checkresult1"] == "pass" and tmp_vars["checkresult2"] == "pass":
        ret_code = 0
        tmp_vars["policyresult"] = "pass"

    if arc3 != 0:
        return (-2, "Failed to invoke module: %s." % astdout3)
    resultjson3 = json.loads(astdout3)
    astdout3 = resultjson3["stdout"]
    astderr3 = resultjson3["stderr"]
    match3 = re.match(r".+", astdout3)
    tmp_vars["systemvalue3"] = astdout3
    if match3:
        tmp_vars["checkresult3"] = "pass"

    if tmp_vars["checkresult1"] == "pass" and tmp_vars["checkresult2"] == "pass" and tmp_vars["checkresult3"] == "pass":
        ret_code = 0
        tmp_vars["policyresult"] = "pass"

    rc, out = curtemplate.render(runcontext.get_template_file('t_8_14.j2'), **tmp_vars)

    if rc == False:
        return (-2, "Failed to render template.%s" % out)

    return ret_code, out
